@@ -119,7 +119,7 @@ output_plugin(const gchar *id)
 	for(l = plugins; l; l = l->next) {
 		GPluginPlugin *plugin = GPLUGIN_PLUGIN(l->data);
 		GPluginPluginInfo *info = gplugin_plugin_get_info(plugin);
-		gboolean internal, loq, bind_global;
+		gboolean internal, loq, bind_global, unloadable;
 		guint32 abi_version;
 		gchar *name, *version;
 		gchar *license_id, *license_text, *license_url;
@@ -155,6 +155,7 @@ output_plugin(const gchar *id)
 			"website", &website,
 			"dependencies", &dependencies,
 			"bind-global", &bind_global,
+			"unloadable", &unloadable,
 			NULL);
 		/* clang-format on */
 
@@ -196,6 +197,7 @@ output_plugin(const gchar *id)
 			printf(MAIN_FORMAT, "internal", (internal) ? "yes" : "no");
 			printf(MAIN_FORMAT, "load on query", (loq) ? "yes" : "no");
 			printf(MAIN_FORMAT, "bind globally", (bind_global) ? "yes" : "no");
+			printf(MAIN_FORMAT, "unloadable", (unloadable) ? "yes" : "no");
 			printf(MAIN_FORMAT, "loader", G_OBJECT_TYPE_NAME(loader));
 
 			g_object_unref(G_OBJECT(loader));
