@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020 Gary Kramlich <grim@reaperworld.com>
+ * Copyright (C) 2011-2021 Gary Kramlich <grim@reaperworld.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -144,10 +144,9 @@ gplugin_test_loader_load_exception(gconstpointer d)
 	g_assert_nonnull(plugin);
 
 	ret = gplugin_manager_load_plugin(manager, plugin, &error);
-	g_assert_false(ret);
-
 	g_assert_error(error, GPLUGIN_DOMAIN, 0);
 	g_clear_error(&error);
+	g_assert_false(ret);
 
 	g_assert_cmpint(
 		gplugin_plugin_get_state(plugin),
@@ -162,6 +161,46 @@ gplugin_test_loader_load_exception(gconstpointer d)
 	g_object_unref(G_OBJECT(plugin));
 }
 
+static void
+gplugin_test_loader_unload_shutdown(gconstpointer d)
+{
+	GPluginLoader *loader = NULL;
+	GPluginManager *manager = NULL;
+	GPluginPlugin *plugin = NULL;
+	GError *error = NULL;
+	gchar *id = NULL;
+	gboolean ret = FALSE;
+
+	manager = gplugin_manager_get_default();
+
+	id = g_strdup_printf("gplugin/%s-unload-shutdown", (const gchar *)d);
+	plugin = gplugin_manager_find_plugin(manager, id);
+	g_free(id);
+	g_assert_nonnull(plugin);
+
+	ret = gplugin_manager_load_plugin(manager, plugin, &error);
+	g_assert_no_error(error);
+	g_assert_true(ret);
+	g_assert_cmpint(
+		gplugin_plugin_get_state(plugin),
+		==,
+		GPLUGIN_PLUGIN_STATE_LOADED);
+
+	loader = gplugin_plugin_get_loader(plugin);
+	ret = gplugin_loader_unload_plugin(loader, plugin, TRUE, &error);
+	g_clear_object(&loader);
+
+	g_assert_no_error(error);
+	g_assert_true(ret);
+
+	g_assert_cmpint(
+		gplugin_plugin_get_state(plugin),
+		==,
+		GPLUGIN_PLUGIN_STATE_QUERIED);
+
+	g_object_unref(G_OBJECT(plugin));
+}
+
 static void
 gplugin_test_loader_unload_failed(gconstpointer d)
 {
@@ -237,6 +276,7 @@ static GPluginTestLoaderFunction test_functions[] = {
 	{"/loaders/%s/load-failed", gplugin_test_loader_load_failed},
 	{"/loaders/%s/load-exception", gplugin_test_loader_load_exception},
 	{"/loaders/%s/unload-failed", gplugin_test_loader_unload_failed},
+	{"/loaders/%s/unload-shutdown", gplugin_test_loader_unload_shutdown},
 	{"/loaders/%s/dependencies", gplugin_test_loader_dependencies},
 	{NULL, NULL},
 };
