@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020 Gary Kramlich <grim@reaperworld.com>
+ * Copyright (C) 2011-2021 Gary Kramlich <grim@reaperworld.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -50,8 +50,11 @@ struct _GPluginLoaderClass {
 
 	gboolean (
 		*load)(GPluginLoader *loader, GPluginPlugin *plugin, GError **error);
-	gboolean (
-		*unload)(GPluginLoader *loader, GPluginPlugin *plugin, GError **error);
+	gboolean (*unload)(
+		GPluginLoader *loader,
+		GPluginPlugin *plugin,
+		gboolean shutdown,
+		GError **error);
 
 	/*< private >*/
 	gpointer reserved[4];
@@ -73,6 +76,7 @@ gboolean gplugin_loader_load_plugin(
 gboolean gplugin_loader_unload_plugin(
 	GPluginLoader *loader,
 	GPluginPlugin *plugin,
+	gboolean shutdown,
 	GError **error);
 
 G_END_DECLS
