@@ -149,7 +149,7 @@ gplugin_manager_foreach_unload_plugin(
 		}
 
 		loader = gplugin_plugin_get_loader(plugin);
-		if(!gplugin_loader_unload_plugin(loader, plugin, &error)) {
+		if(!gplugin_loader_unload_plugin(loader, plugin, TRUE, &error)) {
 			g_warning(
 				"failed to unload plugin with id %s: %s",
 				id,
@@ -508,7 +508,16 @@ gplugin_manager_private_uninit(void)
 
 	g_regex_unref(dependency_regex);
 
-	g_clear_object(&default_manager);
+	/* g_clear_pointer (and therefore g_clear_object), clears the pointer
+	 * before calling the destroy function. So we have to handle this ourself
+	 * and clear the pointer after destruction since plugins are unloaded
+	 * during destruction and may need to unregister a loader during their
+	 * unload.
+	 */
+	if(default_manager != NULL) {
+		g_object_unref(G_OBJECT(default_manager));
+		default_manager = NULL;
+	}
 }
 
 /******************************************************************************
@@ -1687,7 +1696,7 @@ gplugin_manager_unload_plugin(
 		return ret;
 	}
 
-	ret = gplugin_loader_unload_plugin(loader, plugin, &real_error);
+	ret = gplugin_loader_unload_plugin(loader, plugin, FALSE, &real_error);
 	if(ret) {
 		g_clear_error(&real_error);
 		g_signal_emit(manager, signals[SIG_UNLOADED], 0, plugin);
