@@ -304,6 +304,7 @@ static gboolean
 gplugin_native_loader_unload(
 	G_GNUC_UNUSED GPluginLoader *loader,
 	GPluginPlugin *plugin,
+	gboolean shutdown,
 	GError **error)
 {
 	GPluginNativePluginUnloadFunc func;
@@ -326,7 +327,7 @@ gplugin_native_loader_unload(
 	}
 
 	/* now call the function */
-	if(!func(plugin, error)) {
+	if(!func(plugin, shutdown, error)) {
 		if(error && *error == NULL)
 			g_set_error_literal(error, GPLUGIN_DOMAIN, 0, _("unknown failure"));
 
@@ -380,4 +381,3 @@ gplugin_native_loader_new(void)
 		NULL);
 	/* clang-format on */
 }
-
