@@ -79,6 +79,7 @@ typedef struct {
 	gboolean load_on_query;
 
 	gboolean bind_global;
+	gboolean unloadable;
 } GPluginPluginInfoPrivate;
 
 /******************************************************************************
@@ -105,6 +106,7 @@ enum {
 	PROP_AUTHORS,
 	PROP_WEBSITE,
 	PROP_DEPENDENCIES,
+	PROP_UNLOADABLE,
 	N_PROPERTIES,
 };
 static GParamSpec *properties[N_PROPERTIES] = {
@@ -333,6 +335,17 @@ gplugin_plugin_info_set_dependencies(
 	priv->dependencies = g_strdupv((gchar **)dependencies);
 }
 
+static void
+gplugin_plugin_info_set_unloadable(GPluginPluginInfo *info, gboolean unloadable)
+{
+	GPluginPluginInfoPrivate *priv =
+		gplugin_plugin_info_get_instance_private(info);
+
+	priv->unloadable = unloadable;
+
+	g_object_notify_by_pspec(G_OBJECT(info), properties[PROP_UNLOADABLE]);
+}
+
 /******************************************************************************
  * Object Stuff
  *****************************************************************************/
@@ -415,6 +428,11 @@ gplugin_plugin_info_get_property(
 				value,
 				gplugin_plugin_info_get_dependencies(info));
 			break;
+		case PROP_UNLOADABLE:
+			g_value_set_boolean(
+				value,
+				gplugin_plugin_info_get_unloadable(info));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, param_id, pspec);
 			break;
@@ -500,6 +518,11 @@ gplugin_plugin_info_set_property(
 				info,
 				g_value_get_boxed(value));
 			break;
+		case PROP_UNLOADABLE:
+			gplugin_plugin_info_set_unloadable(
+				info,
+				g_value_get_boolean(value));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, param_id, pspec);
 			break;
@@ -841,6 +864,21 @@ gplugin_plugin_info_class_init(GPluginPluginInfoClass *klass)
 		G_TYPE_STRV,
 		G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_CONSTRUCT_ONLY);
 
+	/**
+	 * GPluginPluginInfo:unloadable:
+	 *
+	 * Sets whether or not a plugin is unloadable. See
+	 * gplugin_plugin_info_get_unloadable() for more information.
+	 *
+	 * Since: 0.35.0
+	 */
+	properties[PROP_UNLOADABLE] = g_param_spec_boolean(
+		"unloadable",
+		"unloadable",
+		"Whether or not plugin is unloadable",
+		TRUE,
+		G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+
 	g_object_class_install_properties(obj_class, N_PROPERTIES, properties);
 }
 
@@ -1267,7 +1305,7 @@ gplugin_plugin_info_get_dependencies(GPluginPluginInfo *info)
  * gplugin_plugin_info_get_bind_global:
  * @info: The #GPluginPluginInfo instance.
  *
- * This propoerty and therefore function is only used by the native plugin
+ * This property and therefore function is only used by the native plugin
  * loader.
  *
  * Returns: %TRUE if the plugin has requested to be loaded with its symbols
@@ -1284,3 +1322,29 @@ gplugin_plugin_info_get_bind_global(GPluginPluginInfo *info)
 
 	return priv->bind_global;
 }
+
+/**
+ * gplugin_plugin_info_get_unloadable:
+ * @info: The #GPluginPluginInfo instance.
+ *
+ * Gets whether or not the plugin is unloadable. Certain libraries can not be
+ * shutdown cleanly and then re-enabled during the life time of a program. A
+ * plugin using one of these libraries should set the
+ * GPluginPluginInfo::unloadable property to %FALSE to tell #GPluginManager to
+ * not even attempt to unload it.
+ *
+ * Returns: %TRUE if the plugin is unloadable, otherwise %FALSE.
+ *
+ * Since: 0.35.0
+ */
+gboolean
+gplugin_plugin_info_get_unloadable(GPluginPluginInfo *info)
+{
+	GPluginPluginInfoPrivate *priv = NULL;
+
+	g_return_val_if_fail(GPLUGIN_IS_PLUGIN_INFO(info), FALSE);
+
+	priv = gplugin_plugin_info_get_instance_private(info);
+
+	return priv->unloadable;
+}
