@@ -52,7 +52,10 @@ basic_load(GPluginPlugin *plugin, GError **error)
 }
 
 static gboolean
-basic_unload(GPluginPlugin *plugin, GError **error)
+basic_unload(
+	GPluginPlugin *plugin,
+	G_GNUC_UNUSED gboolean shutdown,
+	GError **error)
 {
 	if(!GPLUGIN_IS_PLUGIN(plugin)) {
 		g_set_error_literal(error, GPLUGIN_DOMAIN, 0, "plugin was not set");
