@@ -36,7 +36,10 @@ unload_failed_load(
 }
 
 static gboolean
-unload_failed_unload(G_GNUC_UNUSED GPluginPlugin *plugin, GError **error)
+unload_failed_unload(
+	G_GNUC_UNUSED GPluginPlugin *plugin,
+	G_GNUC_UNUSED gboolean shutdown,
+	GError **error)
 {
 	g_set_error(error, GPLUGIN_DOMAIN, 0, "expected error");
 
