@@ -37,7 +37,10 @@ bar_load(G_GNUC_UNUSED GPluginPlugin *plugin, G_GNUC_UNUSED GError **error)
 }
 
 static gboolean
-bar_unload(G_GNUC_UNUSED GPluginPlugin *plugin, G_GNUC_UNUSED GError **error)
+bar_unload(
+	G_GNUC_UNUSED GPluginPlugin *plugin,
+	G_GNUC_UNUSED gboolean shutdown,
+	G_GNUC_UNUSED GError **error)
 {
 	return TRUE;
 }
