@@ -37,7 +37,10 @@ exact1_load(G_GNUC_UNUSED GPluginPlugin *plugin, G_GNUC_UNUSED GError **error)
 }
 
 static gboolean
-exact1_unload(G_GNUC_UNUSED GPluginPlugin *plugin, G_GNUC_UNUSED GError **error)
+exact1_unload(
+	G_GNUC_UNUSED GPluginPlugin *plugin,
+	G_GNUC_UNUSED gboolean shutdown,
+	G_GNUC_UNUSED GError **error)
 {
 	return TRUE;
 }
