@@ -37,7 +37,10 @@ fez_load(G_GNUC_UNUSED GPluginPlugin *plugin, G_GNUC_UNUSED GError **error)
 }
 
 static gboolean
-fez_unload(G_GNUC_UNUSED GPluginPlugin *plugin, G_GNUC_UNUSED GError **error)
+fez_unload(
+	G_GNUC_UNUSED GPluginPlugin *plugin,
+	G_GNUC_UNUSED gboolean shutdown,
+	G_GNUC_UNUSED GError **error)
 {
 	return TRUE;
 }
