@@ -50,38 +50,6 @@ _gplugin_lua_error_to_gerror(lua_State *L, GError **error)
 	g_set_error_literal(error, GPLUGIN_DOMAIN, 0, (msg) ? msg : "Unknown");
 }
 
-static gboolean
-_gplugin_lua_loader_load_unload_plugin(
-	G_GNUC_UNUSED GPluginLoader *loader,
-	GPluginPlugin *plugin,
-	const gchar *function,
-	GError **error)
-{
-	gboolean ret = TRUE;
-	lua_State *L = gplugin_lua_plugin_get_state(GPLUGIN_LUA_PLUGIN(plugin));
-
-	lua_getglobal(L, function);
-	lua_pushlightuserdata(L, plugin);
-	if(lua_pcall(L, 1, 1, 0) != 0) {
-		_gplugin_lua_error_to_gerror(L, error);
-
-		return FALSE;
-	}
-
-	if(!lua_isboolean(L, -1)) {
-		_gplugin_lua_error_to_gerror(L, error);
-
-		return FALSE;
-	}
-
-	if(!lua_toboolean(L, -1)) {
-		ret = FALSE;
-		_gplugin_lua_error_to_gerror(L, error);
-	}
-
-	return ret;
-}
-
 /******************************************************************************
  * GPluginLoaderInterface API
  *****************************************************************************/
@@ -162,24 +130,62 @@ gplugin_lua_loader_load(
 	GPluginPlugin *plugin,
 	GError **error)
 {
-	return _gplugin_lua_loader_load_unload_plugin(
-		loader,
-		plugin,
-		"gplugin_load",
-		error);
+	gboolean ret = TRUE;
+	lua_State *L = gplugin_lua_plugin_get_state(GPLUGIN_LUA_PLUGIN(plugin));
+
+	lua_getglobal(L, "gplugin_load");
+	lua_pushlightuserdata(L, plugin);
+	if(lua_pcall(L, 1, 1, 0) != 0) {
+		_gplugin_lua_error_to_gerror(L, error);
+
+		return FALSE;
+	}
+
+	if(!lua_isboolean(L, -1)) {
+		_gplugin_lua_error_to_gerror(L, error);
+
+		return FALSE;
+	}
+
+	if(!lua_toboolean(L, -1)) {
+		ret = FALSE;
+		_gplugin_lua_error_to_gerror(L, error);
+	}
+
+	return ret;
 }
 
 static gboolean
 gplugin_lua_loader_unload(
 	GPluginLoader *loader,
 	GPluginPlugin *plugin,
+	gboolean shutdown,
 	GError **error)
 {
-	return _gplugin_lua_loader_load_unload_plugin(
-		loader,
-		plugin,
-		"gplugin_unload",
-		error);
+	gboolean ret = TRUE;
+	lua_State *L = gplugin_lua_plugin_get_state(GPLUGIN_LUA_PLUGIN(plugin));
+
+	lua_getglobal(L, "gplugin_unload");
+	lua_pushlightuserdata(L, plugin);
+	lua_pushboolean(L, shutdown);
+	if(lua_pcall(L, 2, 1, 0) != 0) {
+		_gplugin_lua_error_to_gerror(L, error);
+
+		return FALSE;
+	}
+
+	if(!lua_isboolean(L, -1)) {
+		_gplugin_lua_error_to_gerror(L, error);
+
+		return FALSE;
+	}
+
+	if(!lua_toboolean(L, -1)) {
+		ret = FALSE;
+		_gplugin_lua_error_to_gerror(L, error);
+	}
+
+	return ret;
 }
 
 /******************************************************************************
