@@ -41,10 +41,14 @@ function gplugin_load(plugin)
 	return true
 end
 
-function gplugin_unload(plugin)
+function gplugin_unload(plugin, shutdown)
 	if plugin == nil then
 		error('plugin is nil')
 	end
 
+	if shutdown then
+		error('shutdown is true')
+	end
+
 	return true
 end
