@@ -29,6 +29,6 @@ function gplugin_load(plugin)
 	return false
 end
 
-function gplugin_unload(plugin)
+function gplugin_unload(plugin, shutdown)
 	return false
 end
