@@ -51,6 +51,7 @@ gplugin_python3_query(G_GNUC_UNUSED GError **error)
 		"website", GPLUGIN_WEBSITE,
 		"category", "loaders",
 		"bind-global", TRUE,
+		"unloadable", FALSE,
 		NULL);
 	/* clang-format on */
 }
@@ -77,15 +78,29 @@ gplugin_python3_load(GPluginPlugin *plugin, GError **error)
 }
 
 static gboolean
-gplugin_python3_unload(G_GNUC_UNUSED GPluginPlugin *plugin, GError **error)
+gplugin_python3_unload(
+	G_GNUC_UNUSED GPluginPlugin *plugin,
+	gboolean shutdown,
+	GError **error)
 {
-	g_set_error_literal(
-		error,
-		GPLUGIN_DOMAIN,
-		0,
-		_("The Python3 loader can not be unloaded"));
+	GPluginManager *manager = NULL;
+	gboolean ret = FALSE;
 
-	return FALSE;
+	if(!shutdown) {
+		g_set_error_literal(
+			error,
+			GPLUGIN_DOMAIN,
+			0,
+			_("The Python3 loader can not be unloaded"));
+
+		return FALSE;
+	}
+
+	manager = gplugin_manager_get_default();
+	ret = gplugin_manager_unregister_loader(manager, loader, error);
+	g_clear_object(&loader);
+
+	return ret;
 }
 
 GPLUGIN_NATIVE_PLUGIN_DECLARE(gplugin_python3)
