@@ -15,14 +15,13 @@
  * License along with this library; if not, see <https://www.gnu.org/licenses/>.
  */
 
+#define PY_SSIZE_T_CLEAN
+#include <Python.h>
+
 #include "gplugin-python3-utils.h"
 
-#include <string.h>
-
 #include <gplugin.h>
 
-#include <Python.h>
-
 gchar *
 gplugin_python3_filename_to_module(const gchar *filename)
 {
@@ -35,15 +34,13 @@ gplugin_python3_filename_to_module(const gchar *filename)
 	base = g_path_get_basename(filename);
 
 	/* now find the last . for the extension */
-	e = g_utf8_strrchr(base, g_utf8_strlen(base, -1), g_utf8_get_char("."));
+	e = g_utf8_strrchr(base, -1, g_utf8_get_char("."));
 	if(e == NULL) {
 		return base;
 	}
 
 	/* now copy the module name into r */
-	r = g_malloc(e - base + 1);
-	memcpy(r, base, e - base);
-	r[e - base] = 0;
+	r = g_strndup(base, e - base);
 
 	/* free the basename */
 	g_free(base);
