@@ -31,5 +31,5 @@ def gplugin_load(plugin):
     return False
 
 
-def gplugin_unload(plugin):
+def gplugin_unload(plugin, shutdown):
     return False
