@@ -45,6 +45,7 @@ gplugin_query(G_GNUC_UNUSED GError **error)
 		"authors", authors,
 		"website", GPLUGIN_WEBSITE,
 		"category", "loaders",
+		"unloadable", FALSE,
 		NULL);
 	/* clang-format on */
 }
@@ -70,13 +71,27 @@ gplugin_load(GPluginNativePlugin *plugin, GError **error)
 }
 
 G_MODULE_EXPORT gboolean
-gplugin_unload(G_GNUC_UNUSED GPluginNativePlugin *plugin, GError **error)
+gplugin_unload(
+	G_GNUC_UNUSED GPluginNativePlugin *plugin,
+	gboolean shutdown,
+	GError **error)
 {
-	g_set_error_literal(
-		error,
-		GPLUGIN_DOMAIN,
-		0,
-		_("The TCC loader can not be unloaded"));
+	GPluginManager *manager = NULL;
+	gboolean ret = FALSE;
 
-	return FALSE;
+	if(!shutdown) {
+		g_set_error_literal(
+			error,
+			GPLUGIN_DOMAIN,
+			0,
+			_("The TCC loader can not be unloaded"));
+
+		return FALSE;
+	}
+
+	manager = gplugin_manager_get_default();
+	ret = gplugin_manager_unregister_loader(manager, loader, error);
+	g_clear_object(&loader);
+
+	return ret;
 }
