@@ -35,7 +35,10 @@ gplugin_load(
 }
 
 G_MODULE_EXPORT gboolean
-gplugin_unload(G_GNUC_UNUSED GPluginNativePlugin *plugin, GError **error)
+gplugin_unload(
+	G_GNUC_UNUSED GPluginNativePlugin *plugin,
+	G_GNUC_UNUSED gboolean shutdown,
+	GError **error)
 {
 	g_set_error(error, GPLUGIN_DOMAIN, 0, "expected error");
 
